# monaco-jsx-highlighter

An extensible library to highlight JSX syntax for the Monaco Editor using JsCodeShift.
 It exposes its AST, so you can add your own syntax-based highlights. 
## Example
See it live in a [React app](https://codesandbox.io/s/monaco-editor-react-6o4u4?file=/src/index.js) 

## Dependencies
It requires [`monaco-editor`](https://www.npmjs.com/package/monaco-editor) and [`jscodeshift`](https://www.npmjs.com/package/jscodeshift), for convenience, they are listed as peer dependencies.

## Installation

Install the package in your project directory with:

```sh
// with npm
npm install monaco-jsx-highlighter

// with yarn
yarn add monaco-jsx-highlighter
```

## Usage
The main method,
`monacoJSXHighlighter.colorizeCode(value: string)`, returns a promise.
 This promise's `then` returns the AST used to highlight the code.

```JavaScript
import monaco from 'monaco-editor';
import j from 'jscodeshift';

import MonacoJSXHighlighter from 'monaco-jsx-highlighter';

const elem = document.getElementById("editor");
const monacoEditor = monaco.editor.create(elem, {
    value: 'const AB=<A x={d}><B>{"hello"}</B></A>;',
    language: 'javascript'
});

const monacoJSXHighlighter = new MonacoJSXHighlighter(monaco, j, monacoEditor);
//enable highlighting
const highlighterDispose =monacoJSXHighlighter.highLightOnDidChangeModelContent();
// to disable it;
//highlighterDispose();

// You can do it directly
monacoJSXHighlighter.colorizeCode();
// triggering the highlighter after each code change
monacoEditor.onDidChangeModelContent(() => {
monacoJSXHighlighter.colorizeCode();
});
```
### Advanced options

```
// Change hover or glyphs behaviors
let defaultOptions = {
    isShowGlyph: true,
    iShowHover: false,
};

const monacoJSXHighlighter = new MonacoJSXHighlighter(monaco, j, monacoEditor, defaultOptions);

// Adding custom highlighting after the JSX highlighting
monacoJSXHighlighter.colorizeCode().then((
                ast, // the ast generate by  JsCodeShift
)=>{
    //... your customization code

    //optional: array with the decorators created by colorize, push your decorator ids to this array
    monacoJSXHighlighter.JSXDecoratorIds.push(...yourdecoratorsIds); 
});

import {JSXTypes, configureLocToMonacoRange} from 'monaco-jsx-highlighter'; 
// JSXTypes:the JSX Syntax types and their monaco CSS classnames.
// locToMonacoRange: converts JsCodeShift locations to Monaco Ranges
locToMonacoRange = configureLocToMonacoRange(monaco);
```

## Customizing via CSS
Take a look of the `src/JSXColoringProvider.css` file and override the CSS classes you need.
 Make sure to import your customization CSS files after you import `monaco-jsx-highlighter`;
